@@ -7,7 +7,6 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.ExpressionEvent;
-import org.gcube.portlets.user.td.widgetcommonevent.shared.expression.C_Expression;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.expression.C_ExpressionContainer;
 import org.gcube.portlets.user.tdtemplate.client.locale.LocaleViewManager;
 import org.gcube.portlets.user.tdtemplate.client.resources.TdTemplateAbstractResources;
@@ -22,6 +21,7 @@ import org.gcube.portlets.user.tdtemplate.shared.SPECIAL_CATEGORY_TYPE;
 import org.gcube.portlets.user.tdtemplate.shared.TdColumnDefinition;
 import org.gcube.portlets.user.tdtemplate.shared.TdTColumnCategory;
 import org.gcube.portlets.user.tdtemplate.shared.TdTTemplateType;
+import org.gcube.portlets.user.tdtemplate.shared.TemplateExpression;
 import org.gcube.portlets.user.tdtemplate.shared.validator.ViolationDescription;
 
 import com.extjs.gxt.ui.client.Style.Scroll;
@@ -118,8 +118,8 @@ public class TdTemplateController implements TdTemplateControllerState{
 						ColumnDefinitionView col = getTdGeneretor().getListColumnDefinition().get(expressionDialogIndexUpdate);
 						
 						if(col!=null){
-							GWT.log("Added rule to column, "+expressionDialogIndexUpdate);
-							col.addRule(rule);
+							GWT.log("Added rule to column: "+expressionDialogIndexUpdate);
+							col.addRule(new TemplateExpression(rule.getExp(), rule.getReadableExpression()), true, true);
 						}
 					}
 				}
@@ -327,16 +327,27 @@ public class TdTemplateController implements TdTemplateControllerState{
 		
 		for (ColumnDefinitionView cDefView : list) {
 			
-			C_ExpressionContainer rule = cDefView.getRuleExpression();
+			//ADDING RULES TODO MORE RULE NOW IS ONLY ONE
+			/*List<TemplateExpression> rules = cDefView.getRulesExpression();
 			C_Expression expression = null;
-			if(rule!=null && rule.getExp()!=null){
-				expression = rule.getExp();
-			}
+			if(rules!=null && rules.size()>0){
+				//TODO FIRST RULE
+				TemplateExpression templateExpression = rules.get(0);
+				expression = templateExpression.getClientExpression();
+			}*/
 			
 			TdColumnDefinition columnDefinition = new TdColumnDefinition(cDefView.getColumnIndex(), cDefView.getSelectedColumnCategory(), cDefView.getSelectedDataType(), cDefView.getSpecialCategoryType());
 			
+			GWT.log("RulesExpression is: "+cDefView.getRulesExpression());
+			if(cDefView.getRulesExpression()!=null){
+				columnDefinition.setRulesExtends(cDefView.getRulesExpression());
+			}
+			
 			if(cDefView.getSpecialCategoryType().equals(SPECIAL_CATEGORY_TYPE.NONE)){
-				columnDefinition.setRuleExpression(expression);
+//				if(cDefView.getRulesExpression()!=null){
+//					columnDefinition.setRulesExtends(cDefView.getRulesExpression());
+//				}
+//				columnDefinition.setRuleExpression(expression);
 			}else if(cDefView.getSpecialCategoryType().equals(SPECIAL_CATEGORY_TYPE.DIMENSION)){
 				columnDefinition.setColumnData(cDefView.getReferenceColumnData());
 			}else if(cDefView.getSpecialCategoryType().equals(SPECIAL_CATEGORY_TYPE.CODENAME)){
@@ -464,9 +475,12 @@ public class TdTemplateController implements TdTemplateControllerState{
 		
 		initLocaleManager(switcherInterface);
 
-		switcher.hide();
+//		switcher.hide();
+		
+		mainPanel.remove(switcher);
 		
 		mainPanel.mask("Building template");
+		mainPanel.setLayout(new FitLayout());
 		mainPanel.add(getTdGeneretor().getTemplatePanel().getPanel());
 		mainPanel.layout(true);
 		
